==> terasoluna-batch4j-all_2.0.0.3.zip: tutorial-batch/sources/jp/terasoluna/batch/tutorial/uc0001/jb0001/DBJobPreLogic.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.batch.tutorial.uc0001.jb0001;

import java.util.Date;

import jp.terasoluna.batch.tutorial.uc0001.JB0001JobContext;

import jp.terasoluna.fw.batch.openapi.BLogicResult;
import jp.terasoluna.fw.batch.openapi.ReturnCode;
import jp.terasoluna.fw.batch.openapi.SupportLogic;
import jp.terasoluna.fw.dao.QueryDAO;

/**
 * WuONXB
 */
public class DBJobPreLogic implements SupportLogic<JB0001JobContext> {

    /**
     * DAONXB
     * SpringɂCX^Xݒ肳B
     */
    private QueryDAO queryDAO = null;
    
    /**
     * WuOsB
     * g^pte[uhg^pth擾AWuReLXgɐݒ肷B
     * @param jobContext WuReLXg
     */
    public BLogicResult execute(JB0001JobContext jobContext) {
        
        //g^pth擾AWuReLXgɐݒ肷B
        Date unyohiduke = queryDAO.executeForObject("UC0001.getUnyohiduke",
                null, Date.class); 
        jobContext.setUnyohiduke(unyohiduke);
        
        //rWlXWbNʃIuWFNgԋpB
        BLogicResult result = new BLogicResult(ReturnCode.NORMAL_CONTINUE);
        return result;
    }

    /**
     * QueryDAOݒ肷B
     * @param queryDAO ݒ肷QueryDAO
     */
    public void setQueryDAO(QueryDAO queryDAO) {
        this.queryDAO = queryDAO;
    }
}

==> terasoluna-batch4j-all_2.0.2.0.zip: tutorial-batch/sources/jp/terasoluna/batch/tutorial/uc0001/jb0001/DBJobPreLogic.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.batch.tutorial.uc0001.jb0001;

import java.util.Date;

import jp.terasoluna.batch.tutorial.uc0001.JB0001JobContext;

import jp.terasoluna.fw.batch.openapi.BLogicResult;
import jp.terasoluna.fw.batch.openapi.ReturnCode;
import jp.terasoluna.fw.batch.openapi.SupportLogic;
import jp.terasoluna.fw.dao.QueryDAO;

/**
 * WuONXB
 */
public class DBJobPreLogic implements SupportLogic<JB0001JobContext> {

    /**
     * DAONXB
     * SpringɂCX^Xݒ肳B
     */
    private QueryDAO queryDAO = null;
    
    /**
     * WuOsB
     * g^pte[uhg^pth擾AWuReLXgɐݒ肷B
     * @param jobContext WuReLXg
     * @return rWlXWbN
     */
    public BLogicResult execute(JB0001JobContext jobContext) {
        
        //g^pth擾AWuReLXgɐݒ肷B
        Date unyohiduke = queryDAO.executeForObject("UC0001.getUnyohiduke",
                null, Date.class);
        jobContext.setUnyohiduke(unyohiduke);
        
        //rWlXWbNʃIuWFNgԋpB
        return new BLogicResult(ReturnCode.NORMAL_CONTINUE);
    }

    /**
     * QueryDAOݒ肷B
     * @param queryDAO ݒ肷QueryDAO
     */
    public void setQueryDAO(QueryDAO queryDAO) {
        this.queryDAO = queryDAO;
    }
}
